<?php

namespace drp\AdminPanel\Sidebar;

class SidebarMultiLevelItem extends SidebarItemBase implements SidebarItemInterface
{
    /**
     * Array of all the items within this sidebar.
     *
     * @var array
     */
    protected $items = [];

    /**
     * Builds the HTML version of this sidebar item.
     *
     * @param  string $currentPath Current path the admin panel is on.
     * @return string
     */
    public function render($currentPath)
    {
        if ($this->shouldRender() === false) {
            return '';
        }

        $html = '<li class="treeview ' . $this->getActive($currentPath) . '">
            <a href="#"><span>' . $this->getIconHtml() . ' ' . $this->text .
                '</span> <i class="fa fa-angle-left pull-right"></i></a>
            <ul class="treeview-menu">';

        foreach ($this->items as $item) {
            $html .= $item->render($currentPath);
        }
        $html .= '</ul></li>';

        return $html;
    }

    /**
     * Gets active class if the current path is within one of this items.
     *
     * @param  string $currentPath
     * @return string
     */
    protected function getActive($currentPath)
    {
        if ($this->containActiveLink($currentPath)) {
            return 'active';
        }

        return '';
    }

    /**
     * Checks if any of the items in this multi level item is the current route.
     * @param  string  $currentPath
     * @return boolean
     */
    public function containActiveLink($currentPath)
    {
        foreach ($this->items as $item) {
            if ($item instanceof SidebarMultiLevelItem) {
                if ($item->containActiveLink($currentPath)) {
                    return true;
                }
            } elseif (trim($item->getLink(), '/') == $currentPath) {
                return true;
            }
        }

        return false;
    }

    /**
     * Adds a single sidebar item.
     *
     * @param  string  $icon         Icon to be displayed to the left of the text.
     * @param  string  $text         Text to be displayed.
     * @param  string  $link         Location the sidebar will take you to.
     * @param  boolean $openInNewTab Whether to open the link in a new tab.
     * @return self
     */
    public function addItem($icon, $text, $link, $openInNewTab = false)
    {
        $item          = new SidebarSingleItem($icon, $text, $link, $openInNewTab);
        $this->items[] = $item;

        return $this;
    }

    /**
     * Adds a multi level item to the sidebar.
     *
     * @param  string                $icon Icon to be displayed to the left of the text.
     * @param  string                $text Text to be displayed.
     * @return SidebarMultiLevelItem
     */
    public function addMultiLevelItem($icon, $text)
    {
        $multiItem     = new SidebarMultiLevelItem($icon, $text);
        $this->items[] = $multiItem;

        return $multiItem;
    }
}
